==> monodevelop_2.0%2Bdfsg.orig.tar.gz: monodevelop-2.0/src/addins/NUnit/Commands/NUnitCommands.cs <==
//
// TestChart.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using Gtk;

using MonoDevelop.Core;
using MonoDevelop.Components;
using MonoDevelop.Components.Commands;
using MonoDevelop.Ide.Gui;
using MonoDevelop.Projects;

namespace MonoDevelop.NUnit.Commands
{
	public enum TestCommands
	{
		RunAllTests,
		RunTest,
		RunTestWith,
		ShowTestCode,
		SelectTestInTree,
		ShowTestDetails
	}
	
	public enum TestChartCommands
	{
		ShowResults,
		ShowTime,
		UseTimeScale,
		SingleDayResult,
		ShowSuccessfulTests,
		ShowFailedTests,
		ShowIgnoredTests
	}
	
	public enum NUnitProjectCommands
	{
		AddAssembly
	}
	
	class RunAllTestsHandler: CommandHandler
	{
		protected override void Run ()
		{
			IWorkspaceObject ob = IdeApp.ProjectOperations.CurrentSelectedBuildTarget;
			if (ob != null) {
				UnitTest test = NUnitService.Instance.FindRootTest (ob);
				if (test != null)
					NUnitService.Instance.RunTest (test, null);
			}
		}
		
		protected override void Update (CommandInfo info)
		{
			IWorkspaceObject ob = IdeApp.ProjectOperations.CurrentSelectedBuildTarget;
			if (ob != null) {
				UnitTest test = NUnitService.Instance.FindRootTest (ob);
				info.Enabled = (test != null);
			} else
				info.Enabled = false;
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/addins/NUnit/Commands/NUnitCommands.cs <==
//
// TestChart.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using MonoDevelop.Components.Commands;
using MonoDevelop.Projects;
using MonoDevelop.Ide;

namespace MonoDevelop.NUnit.Commands
{
	public enum TestCommands
	{
		RunAllTests,
		RunTest,
		RunTestWith,
		ShowTestCode,
		SelectTestInTree,
		ShowTestDetails,
		GoToFailure
	}
	
	public enum TestChartCommands
	{
		ShowResults,
		ShowTime,
		UseTimeScale,
		SingleDayResult,
		ShowSuccessfulTests,
		ShowFailedTests,
		ShowIgnoredTests
	}
	
	public enum NUnitProjectCommands
	{
		AddAssembly
	}
	
	class RunAllTestsHandler: CommandHandler
	{
		protected override void Run ()
		{
			IWorkspaceObject ob = IdeApp.ProjectOperations.CurrentSelectedBuildTarget;
			if (ob != null) {
				UnitTest test = NUnitService.Instance.FindRootTest (ob);
				if (test != null)
					NUnitService.Instance.RunTest (test, null);
			}
		}
		
		protected override void Update (CommandInfo info)
		{
			IWorkspaceObject ob = IdeApp.ProjectOperations.CurrentSelectedBuildTarget;
			if (ob != null) {
				UnitTest test = NUnitService.Instance.FindRootTest (ob);
				info.Enabled = (test != null);
			} else
				info.Enabled = false;
		}
	}
}
